==> aws-cdk.integ-tests-1.153.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_integ_tests_IntegTestCaseProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.stacks))
            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_Stack(p.stacks);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_integ_tests_IntegTestCase(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_integ_tests_IntegTestCaseProps, _aws_cdk_integ_tests_IntegTestCase };

==> aws-cdk.integ-tests-1.156.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_integ_tests_IntegTestCaseProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.stacks))
            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_Stack(p.stacks);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_integ_tests_IntegTestCase(p) {
}
function _aws_cdk_integ_tests_IntegTestProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.testCases))
            _aws_cdk_integ_tests_IntegTestCase(p.testCases);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_integ_tests_IntegTest(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_integ_tests_IntegTestCaseProps, _aws_cdk_integ_tests_IntegTestCase, _aws_cdk_integ_tests_IntegTestProps, _aws_cdk_integ_tests_IntegTest };
